@@ -21,7 +21,7 @@ class Foot(DynamicDocument):
     # 请求结束时间：
     request_end_time = DateTimeField()
 
-    cookies = StringField()
+    cookies = DictField()
     # 请求头
     headers = DictField()
     # 请求方式
